PayloadTypeName

Trait PayloadTypeName 

pub trait PayloadTypeName {
    const PAYLOAD_TYPE_NAME: &'static str;
}
This trait is used to ensure that the payload type has a topic associated with it.

Required Associated Constants

const PAYLOAD_TYPE_NAME: &'static str

The topic name associated with this payload type, used for routing/dispatch.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors